/*******************************************************
 *
 * $GAMGI/src/gtk/molecule/gamgi_gtk_molecule_select.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static void static_ok (GtkWidget *widget, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_molecule_select_press (gamgi_window *window_mouse,    
GdkEventButton *event, int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_molecule_select (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Not implemented yet.

 *************
 * Rationale *
 *************/
